| MedxR | R Documentation |
This package provides functions to access drug regulatory data from public RESTful APIs including the FDA Open API and the Health Canada Drug Product Database API, retrieving real-time or historical information on drug approvals, adverse events, recalls, and product details. Additionally, the package includes a curated collection of open datasets focused on drugs, pharmaceuticals, treatments, and clinical studies.
MedxR: Access Drug Regulatory Data via FDA and Health Canada APIs
Access Drug Regulatory Data via FDA and Health Canada APIs.
Maintainer: Renzo Caceres Rossi arenzocaceresrossi@gmail.com
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.