This dataset, oral_anticoagulants_df, is a data frame containing results from 34 studies evaluating the effectiveness of oral anticoagulants in patients with coronary artery disease. The dataset includes study metadata and outcome counts for treatment and control groups, as well as intensity classifications.
data(oral_anticoagulants_df)A data frame with 34 observations and 9 variables:
Character variable identifying each study
Integer variable indicating the publication year
Character variable describing treatment intensity
Integer variable indicating the number of aspirin users in the treatment group
Integer variable indicating the number of aspirin users in the control group
Integer variable indicating the number of adverse events in the treatment group
Integer variable for the sample size of the treatment group
Integer variable indicating the number of adverse events in the control group
Integer variable for the sample size of the control group
The dataset name has been kept as 'oral_anticoagulants_df' to avoid confusion with other datasets in the R ecosystem. This naming convention helps distinguish this dataset as part of the MedxR package and assists users in identifying its specific characteristics. The suffix 'df' indicates that the dataset is a data frame. The original content has not been modified in any way.