This function sends a GET request to the FDA openFDA API.
It supports caching via the memoise package to avoid redundant calls,
and respects a rate limit between successive API requests.
The Drugs at FDA database contains information about drug products approved
since 1939. The majority of labels, approval letters, and reviews are
available for products approved since 1998. This database includes brand
name drugs, generic drugs, and therapeutic biological products.
If the API request fails, returns no matches, or returns an error status code,
the function returns NULL with an informative message.