Retrieves drug products from the Health Canada Drug Product Database (DPD)
that match a specific brand (commercial) name using the RESTful API endpoint
/drug/drugproduct?search=<brand_name>.
This includes details such as the Drug Identification Number (DIN),
product name, class, number of active ingredients, company name,
and update date for each approved or discontinued pharmaceutical product.